Collector

Struct Collector 

pub struct Collector { /* private fields */ }
Prometheus style process metrics collector for the metrics crate.

This is a collector which will directly export the metrics to the registered metrics collector.

Implementations

Source

impl Collector

pub fn prefix(self, prefix: impl Into<String>) -> Self

👎Deprecated since 1.1.0:

Use Collector::new(prefix).

Add an prefix that is prepended to metric keys.

Examples
let collector = Collector::default().prefix("my_prefix_");
Deprecated

The new interface for creating a Collector should be utilized.

let collector = Collector::new("my_prefix_");
pub fn new(prefix: impl AsRef<str>) -> Self

Create a new Collector instance with the provided prefix that is prepended to metric keys.

Examples
let collector = Collector::default();
pub fn describe(&self)

Describe available metrics through describe_counter! and describe_gauge! macro of metrics crate.

Example
// Recorder must be initialized prior to describe.
let builder = PrometheusBuilder::new();
builder.install().expect("failed to install recorder/exporter");

let collector = Collector::default();
// Describe collector
collector.describe();
pub fn collect(&self)

Collect metrics and record through counter! and gauge! macro of metrics crate.

Example
// Recorder must be initialized prior to describe.
let builder = PrometheusBuilder::new();
builder.install().expect("failed to install recorder/exporter");

let collector = Collector::default();
collector.describe();
// Collect metrics
collector.collect();